@@ -101,7 +101,7 @@ class Path(starlette.routing.Route):
             # detects it as an ASGI app and passes us the raw Scope, Receive and Send
             # as well as not wrapping it in a threadpool
             endpoint=_PathApp(operations),  # type: ignore[arg-type]
-            name=name,  # type: ignore[arg-type]
+            name=name or path,
             include_in_schema=include_in_schema,
             methods=list(operations.keys()),
         )
